# AttachmentStepDto


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**attachment_id** | **int** |  | [optional] 

## Example

```python
from src.client.generated.models.attachment_step_dto import AttachmentStepDto

# TODO update the JSON string below
json = "{}"
# create an instance of AttachmentStepDto from a JSON string
attachment_step_dto_instance = AttachmentStepDto.from_json(json)
# print the JSON string representation of the object
print(AttachmentStepDto.to_json())

# convert the object into a dict
attachment_step_dto_dict = attachment_step_dto_instance.to_dict()
# create an instance of AttachmentStepDto from a dict
attachment_step_dto_from_dict = AttachmentStepDto.from_dict(attachment_step_dto_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


